Helpviewer/HelpDocsInstaller.py

changeset 15
f6ccc31d6e72
parent 13
1af94a91f439
child 18
3b1f5d872fd7
diff -r 092aa8fafa4e -r f6ccc31d6e72 Helpviewer/HelpDocsInstaller.py
--- a/Helpviewer/HelpDocsInstaller.py	Sat Jan 02 16:15:57 2010 +0000
+++ b/Helpviewer/HelpDocsInstaller.py	Sat Jan 02 17:09:08 2010 +0000
@@ -12,7 +12,7 @@
 from PyQt4.QtGui import *
 from PyQt4.QtHelp import QHelpEngineCore
 
-from eric4config import getConfig
+from eric5config import getConfig
 
 class HelpDocsInstaller(QThread):
     """
@@ -138,12 +138,12 @@
     
     def __installEric4Doc(self, engine):
         """
         Private method to install/update the eric4 help documentation.
         
         @param engine reference to the help engine (QHelpEngineCore)
         @return flag indicating success (boolean)
         """
-        versionKey = "eric4_ide"
+        versionKey = "eric5_ide"
         info = engine.customValue(versionKey, "")
         lst = info.split('|')
         
@@ -191,4 +191,4 @@
                     fi.absoluteFilePath())
                 return True
         
-        return False
+        return False
\ No newline at end of file
@@ -138,12 +138,12 @@
     def __installEric4Doc(self, engine):
         """
-        Private method to install/update the eric4 help documentation.
+        Private method to install/update the eric5 help documentation.
         
         @param engine reference to the help engine (QHelpEngineCore)

eric ide

mercurial